dismiss_version

Function dismiss_version 

pub fn dismiss_version(config: &UpdateConfig, version: &str) -> Result<()>
Persist a dismissal for the current latest version so we don’t show the update popup again for this version.